@@ -17,9 +17,11 @@
 """
 
 from .loaddata import loadData
+from .serialization import serialize_data, deserialize_data
 from .resample import resample
 
 # silence the pyflakes syntax checker
 assert loadData or resample or True
+assert serialize_data or deserialize_data or True
 
 # End of file
